@@ -32,7 +32,6 @@
 
 """|UDM| basic functionality"""
 
-from __future__ import absolute_import, print_function
 
 import copy
 import re
@@ -41,7 +40,6 @@ import time
 from logging import getLogger
 from typing import TYPE_CHECKING, Any, Callable, Container, Iterable, Match, Type  # noqa: F401
 
-import six
 import unidecode
 from ldap.filter import filter_format
 
@@ -60,10 +58,6 @@ if TYPE_CHECKING:
 
 __all__ = ('configRegistry', 'extended_attribute', 'hook', 'mapping', 'modules', 'objects', 'option', 'pattern_replace', 'policiesGroup', 'property', 'syntax', 'ucr_overwrite_layout', 'ucr_overwrite_module_layout', 'ucr_overwrite_properties')
 
-if six.PY2:
-    # baseconfig legacy
-    baseConfig = configRegistry
-
 ucr_property_prefix = 'directory/manager/web/modules/%s/properties/'
 
 
@@ -110,7 +104,8 @@ def ucr_overwrite_properties(module, lo):
                                 syntax._load(lo)
                                 setattr(prop, attr, syntax)
                             else:
-                                log.error("ucr_overwrite_properties: UCR variable %s does not refer to a known UDM syntax: '%s'", var, new_prop_val)
+                                syntax = univention.admin.syntax.string()
+                                setattr(prop, attr, syntax())
                     elif prop_val_type is bool:
                         setattr(prop, attr, configRegistry.is_true(None, None, new_prop_val))
                     else:
@@ -324,7 +319,7 @@ class property:
         if not base_default:
             return self.new()
 
-        if isinstance(base_default, six.string_types):
+        if isinstance(base_default, str):
             return self._replace(base_default, object)
 
         bd0 = base_default[0]
@@ -333,7 +328,7 @@ class property:
         if getattr(self.syntax, 'subsyntaxes', None) is not None and isinstance(bd0, (list, tuple)) and not self.multivalue:
             return bd0
 
-        if isinstance(bd0, six.string_types):
+        if isinstance(bd0, str):
             # multivalue defaults will only be a part of templates, so not multivalue is the common way for modules
             if not self.multivalue:  # default=(template-str, [list-of-required-properties])
                 if all(object[p] for p in base_default[1]):
@@ -342,7 +337,7 @@ class property:
                     return bd0
                 return self.new()
             else:  # multivalue
-                if all(isinstance(bd, six.string_types) for bd in base_default):
+                if all(isinstance(bd, str) for bd in base_default):
                     return [self._replace(bd, object) for bd in base_default]
                 # must be a list of loaded extended attributes then, so we return it if it has content
                 # return the first element, this is only related to empty extended attributes which are loaded wrong, needs to be fixed elsewhere
@@ -523,93 +518,6 @@ class extended_attribute(object):
         return " univention.admin.extended_attribute: { name: '%s', oc: '%s', attr: '%s', delOC: '%s', syntax: '%s', hook: '%s' }" % (self.name, self.objClass, self.ldapMapping, self.deleteObjClass, self.syntax, hook)
 
 
-if six.PY2:  # deprecated, use layout.Tab instead
-    class tab:
-        """|UDM| tab to group related properties together in |UMC|."""
-
-        is_app_tab = False
-
-        def __init__(self, short_description='', long_description='', fields=[], advanced=False, help_text=None):
-            self.short_description = short_description
-            self.long_description = long_description
-            self.fields = fields
-            self.advanced = advanced
-            self.help_text = help_text
-
-        def set_fields(self, fields):
-            self.fields = fields
-
-        def get_fields(self):
-            return self.fields
-
-        def __repr__(self):
-            string = " univention.admin.tab: { short_description: '%s', long_description: '%s', advanced: '%s', fields: [" % (self.short_description, self.long_description, self.advanced)
-            for field in self.fields:
-                string = "%s %s," % (string, field)
-            return string + " ] }"
-
-
-if six.PY2:  # deprecated, use layout.Group instead
-    class field:  # noqa: PLW1641
-        """
-        >>> field('bar') < field('foo')
-        True
-        >>> field('bar') <= field('foo')
-        True
-        >>> field('bar') == field('foo')
-        False
-        >>> field('bar') != field('foo')
-        True
-        >>> field('bar') >= field('foo')
-        False
-        >>> field('bar') > field('foo')
-        False
-        >>> field('registry') < field('foo')
-        True
-        >>> field('registry') <= field('foo')
-        True
-        >>> field('registry') >= field('foo')
-        False
-        >>> field('registry') > field('foo')
-        False
-        """
-
-        def __init__(self, property='', type='', first_only=0, short_description='', long_description='', hide_in_resultmode=0, hide_in_normalmode=0, colspan=None, width=None):
-            self.property = property
-            self.type = type
-            self.first_only = first_only
-            self.short_description = short_description
-            self.long_description = long_description
-            self.hide_in_resultmode = hide_in_resultmode
-            self.hide_in_normalmode = hide_in_normalmode
-            self.colspan = colspan
-            self.width = width
-
-        def __repr__(self):
-            return " univention.admin.field: { short_description: '%s', long_description: '%s', property: '%s', type: '%s', first_only: '%s', hide_in_resultmode: '%s', hide_in_normalmode: '%s', colspan: '%s', width: '%s' }" % (
-                self.short_description, self.long_description, self.property, self.type, self.first_only, self.hide_in_resultmode, self.hide_in_normalmode, self.colspan, self.width)
-
-        # at the moment the sort is only needed for layout of the registry module
-
-        def __lt__(self, other):
-            return (self.property != 'registry', self.property) < (other.property != 'registry', other.property) if isinstance(other, field) else NotImplemented
-
-        def __le__(self, other):
-            return (self.property != 'registry', self.property) <= (other.property != 'registry', other.property) if isinstance(other, field) else NotImplemented
-
-        def __eq__(self, other):
-            return self.property == other.property if isinstance(other, field) else NotImplemented
-
-        def __ne__(self, other):
-            return self.property != other.property if isinstance(other, field) else NotImplemented
-
-        def __ge__(self, other):
-            return (self.property != 'registry', self.property) >= (other.property != 'registry', other.property) if isinstance(other, field) else NotImplemented
-
-        def __gt__(self, other):
-            return (self.property != 'registry', self.property) > (other.property != 'registry', other.property) if isinstance(other, field) else NotImplemented
-
-
 class policiesGroup:
 
     def __init__(self, id, short_description=None, long_description='', members=[]):
