@@ -34,7 +34,6 @@
 
 from typing import Any  # noqa: F401
 
-import six
 from ldap.dn import str2dn
 
 import univention.admin.filter as udm_filter
@@ -212,4 +211,4 @@ def stripDot(old, encoding=()):
         return [stripDot(_, encoding) for _ in old]
     if old is None:
         return old
-    return old[:-1].encode(*encoding) if isinstance(old, (bytes, six.text_type)) and old.endswith('.') else old.encode(*encoding)
+    return old[:-1].encode(*encoding) if isinstance(old, (bytes, str)) and old.endswith('.') else old.encode(*encoding)
