@@ -35,7 +35,6 @@
 import univention.admin.filter
 import univention.admin.handlers
 import univention.admin.localization
-from univention.admin._ucr import configRegistry as ucr
 from univention.admin.layout import Group, Tab
 
 
@@ -317,7 +316,7 @@ layout = [
             "phone",
             ['roomNumber', 'departmentNumber'],
             ['street', 'postcode', 'city'],
-            ['state', 'country'] if not ucr.is_true('directory/manager/web/modules/users/user/map-country-to-st') else ['country'],
+            ['state', 'country'],
         ]),
     ]),
 ]
@@ -339,11 +338,8 @@ mapping.register('sambahome', 'sambaHomePath', None, univention.admin.mapping.Li
 mapping.register('scriptpath', 'sambaLogonScript', None, univention.admin.mapping.ListToString)
 mapping.register('profilepath', 'sambaProfilePath', None, univention.admin.mapping.ListToString)
 mapping.register('homedrive', 'sambaHomeDrive', None, univention.admin.mapping.ListToString, encoding='ASCII')
-if ucr.is_true('directory/manager/web/modules/users/user/map-country-to-st'):  # old broken behavior
-    mapping.register('country', 'st', None, univention.admin.mapping.ListToString)
-else:
-    mapping.register('country', 'c', None, univention.admin.mapping.ListToString)
-    mapping.register('state', 'st', None, univention.admin.mapping.ListToString)
+mapping.register('country', 'c', None, univention.admin.mapping.ListToString)
+mapping.register('state', 'st', None, univention.admin.mapping.ListToString)
 mapping.register('phone', 'telephoneNumber')
 mapping.register('roomNumber', 'roomNumber')
 mapping.register('employeeNumber', 'employeeNumber', None, univention.admin.mapping.ListToString)
@@ -396,7 +392,7 @@ class object(univention.admin.handlers.simpleLdap):
             for x in ml:
                 if x[0].lower() != 'objectClass'.lower():
                     yield x
-                elif isinstance(x[-1], (bytes, str, type(u''))):
+                elif isinstance(x[-1], (bytes, str)):
                     if x[-1] not in BLACKLISTED_OBJECT_CLASSES:
                         yield x
                     elif len(x) == 3:
