@@ -34,8 +34,6 @@
 
 import copy
 
-import six
-
 
 class ILayoutElement(dict):
     """Describes the layout information for a tab or a groupbox."""
@@ -69,7 +67,7 @@ class ILayoutElement(dict):
             if replaced:
                 new_layout.append(item)
                 continue
-            if isinstance(item, six.string_types) and item == old:
+            if isinstance(item, str) and item == old:
                 new_layout.append(new)
                 replaced = True
             elif isinstance(item, (tuple, list)):
@@ -98,7 +96,7 @@ class ILayoutElement(dict):
                 if removed:
                     new_layout.append(item)
                     continue
-                if isinstance(item, six.string_types) and item != field:
+                if isinstance(item, str) and item != field:
                     new_layout.append(item)
                 elif isinstance(item, (tuple, list)):
                     line = []
@@ -119,7 +117,7 @@ class ILayoutElement(dict):
 
     def exists(self, field):
         for item in self.layout:
-            if isinstance(item, six.string_types) and item == field:
+            if isinstance(item, str) and item == field:
                 return True
             elif isinstance(item, (tuple, list)):
                 if field in item:
@@ -142,7 +140,7 @@ class ILayoutElement(dict):
         if len(self.layout) <= currentLine or currentLine < 0:
             self.layout.append(field)
         else:
-            if isinstance(self.layout[currentLine], six.string_types):
+            if isinstance(self.layout[currentLine], str):
                 if fpos == 0:
                     self.layout[currentLine] = [field, self.layout[currentLine]]
                 else:
