@@ -32,7 +32,6 @@
 
 """Functions to map between |UDM| properties and |LDAP| attributes."""
 
-from __future__ import absolute_import
 
 import base64
 import inspect
@@ -52,19 +51,12 @@ _ = translation.translate
 _E = TypeVar('_E')  # noqa: PYI018
 _Encoding = Tuple[str, ...]
 
-getfullargspec = getattr(inspect, 'getfullargspec', getattr(inspect, 'getargspec'))  # noqa: B009
-
-try:
-    unicode  # type: ignore[used-before-def] # noqa: B018
-except NameError:
-    unicode = str
-
 
 def MapToBytes(udm_value, encoding=()):
     # type: (list[str] | tuple[str, ...] | str, _Encoding) -> list[bytes] | bytes
     if isinstance(udm_value, (list, tuple)):
         return [MapToBytes(udm_val, encoding=encoding) for udm_val in udm_value]
-    return unicode(udm_value).encode(*encoding)
+    return str(udm_value).encode(*encoding)
 
 
 def UnmapToUnicode(ldap_value, encoding=()):
@@ -295,7 +287,7 @@ def unmapUNIX_TimeInterval(seconds):
             if value % 24 == 0:
                 value //= 24
                 unit = u'days'
-    return [unicode(value), unit]
+    return [str(value), unit]
 
 
 def mapUNIX_TimeInterval(value):
@@ -327,7 +319,7 @@ def mapUNIX_TimeInterval(value):
         val *= 60 * 60
     elif unit == u'minutes':
         val *= 60
-    return unicode(val).encode('ASCII')
+    return str(val).encode('ASCII')
 
 
 def unmapBase64(value):
@@ -567,7 +559,7 @@ class mapping(object):
         if not map_value:
             map_value = MapToBytes
         kwargs = {}
-        if 'encoding' in getfullargspec(map_value).args:
+        if 'encoding' in inspect.getfullargspec(map_value).args:
             kwargs['encoding'] = (encoding, strictness)
 
         try:
@@ -615,7 +607,7 @@ class mapping(object):
 
         encoding, strictness = self._unmap_encoding.get(unmap_name, ('UTF-8', 'strict'))
         kwargs = {}
-        if 'encoding' in getfullargspec(unmap_value).args:
+        if 'encoding' in inspect.getfullargspec(unmap_value).args:
             kwargs['encoding'] = (encoding, strictness)
 
         try:
@@ -629,7 +621,7 @@ class mapping(object):
         info = mapDict(self, oldattr)
         for key, func in self._unmap_func.items():
             kwargs = {}
-            if 'encoding' in getfullargspec(func).args:
+            if 'encoding' in inspect.getfullargspec(func).args:
                 kwargs['encoding'] = self._unmap_encoding.get(key, ('UTF-8', 'strict'))
             info[key] = func(oldattr, **kwargs)
         return info
