@@ -33,19 +33,17 @@
 
 """|UDM| access to handler modules."""
 
-from __future__ import absolute_import
 
 import copy
 import importlib
 import locale
 import os
+from importlib import reload as reload_module
 from logging import getLogger
-from typing import Any, Text, Union, overload  # noqa: F401
+from typing import Any, Protocol, Union, overload  # noqa: F401
 
 import ldap
-import six
 from ldap.filter import filter_format
-from six.moves import reload_module
 
 import univention.admin
 import univention.admin.handlers
@@ -57,54 +55,50 @@ from univention.admin._ucr import configRegistry
 from univention.admin.layout import Group, ILayoutElement, Tab
 
 
-try:
-    from typing_extensions import Protocol
+class UdmModule(Protocol):
+    module = ''  # type: str
+    childs = False  # type: bool
+    childmodules = []  # type: list[str]
+    operations = []  # type: list[str]
+    short_description = ''  # type: str
+    object_name = ''  # type: str
+    object_name_plural = ''  # type: str
+    long_description = ''  # type: str
+    options = {}  # type: dict[str, univention.admin.option]
+    property_descriptions = {}  # type: dict[str, univention.admin.property]
+    default_property_descriptions = {}  # type: dict[str, univention.admin.property]
+    policy_apply_to = []  # type: list[str]
+    policy_position_dn_prefix = ''  # type: str
+    policy_oc = ''  # type: str
+    docleanup = False  # type: bool
+    layout = []  # type: list[Tab]
+    mapping = None  # type: univention.admin.mapping.mapping
+    initialized = False  # type: bool
+    extended_attribute_tabnames = []  # type: list[str]
+    extended_udm_attributes = []  # type: list[univention.admin.extended_attribute]
 
-    class UdmModule(Protocol):
-        module = ''  # type: str
-        childs = False  # type: bool
-        childmodules = []  # type: list[str]
-        operations = []  # type: list[str]
-        short_description = ''  # type: str
-        object_name = ''  # type: str
-        object_name_plural = ''  # type: str
-        long_description = ''  # type: str
-        options = {}  # type: dict[str, univention.admin.option]
-        property_descriptions = {}  # type: dict[str, univention.admin.property]
-        default_property_descriptions = {}  # type: dict[str, univention.admin.property]
-        policy_apply_to = []  # type: list[str]
-        policy_position_dn_prefix = ''  # type: str
-        policy_oc = ''  # type: str
-        docleanup = False  # type: bool
-        layout = []  # type: list[Tab]
-        mapping = None  # type: univention.admin.mapping.mapping
-        initialized = False  # type: bool
-        extended_attribute_tabnames = []  # type: list[str]
-        extended_udm_attributes = []  # type: list[univention.admin.extended_attribute]
-
-        class object:
-            def __init__(self, co, lo, position, dn=u'', superordinate=None, attributes=None):
-                # type: (None, univention.admin.uldap.access, univention.admin.uldap.position, Text, univention.admin.handlers.simpleLdap | None, univention.admin.handlers._Attributes | None) -> None
-                pass
-
-        @staticmethod
-        def identify(dn, attr):
-            # type: (str, dict[str, list[Any]]) -> bool
+    class object:
+        def __init__(self, co, lo, position, dn=u'', superordinate=None, attributes=None):
+            # type: (None, univention.admin.uldap.access, univention.admin.uldap.position, str, univention.admin.handlers.simpleLdap | None, univention.admin.handlers._Attributes | None) -> None
             pass
 
-        @staticmethod
-        def lookup(co, lo, filter='', base='', superordinate=None, scope='base+one', unique=False, required=False, timeout=-1, sizelimit=0):
-            # type: (None, univention.admin.uldap.access, str, str, Any, str, bool, bool, int, int) -> list[Any]
-            pass
+    @staticmethod
+    def identify(dn, attr):
+        # type: (str, dict[str, list[Any]]) -> bool
+        pass
 
-        @staticmethod
-        def lookup_filter(filter_s=None, lo=None):
-            # type: (str | None, univention.admin.uldap.access | None) -> univention.admin.filter.conjunction
-            pass
+    @staticmethod
+    def lookup(co, lo, filter='', base='', superordinate=None, scope='base+one', unique=False, required=False, timeout=-1, sizelimit=0):
+        # type: (None, univention.admin.uldap.access, str, str, Any, str, bool, bool, int, int) -> list[Any]
+        pass
 
-    UdmName = Union[UdmModule, str]
-except ImportError:
-    pass
+    @staticmethod
+    def lookup_filter(filter_s=None, lo=None):
+        # type: (str | None, univention.admin.uldap.access | None) -> univention.admin.filter.conjunction
+        pass
+
+
+UdmName = Union[UdmModule, str]
 
 log = getLogger('ADMIN')
 
@@ -190,7 +184,7 @@ def get(module):
     # FIXME: raise Exception instead of returning None
     if not module:
         return None  # type: ignore
-    if isinstance(module, six.string_types):
+    if isinstance(module, str):
         return modules.get(module)  # type: ignore
     return module  # type: ignore[return-value]
 
@@ -206,7 +200,7 @@ def _get(module):
     """
     if not modules:
         update()
-    if isinstance(module, six.string_types):
+    if isinstance(module, str):
         return modules[module]
     return module
 
@@ -741,7 +735,7 @@ def superordinate_names(module_name):
     """Return name of superordinate module."""
     module = get(module_name)
     names = getattr(module, 'superordinate', [])
-    if isinstance(names, six.string_types):
+    if isinstance(names, str):
         names = [names]
     return names
 
@@ -833,7 +827,7 @@ def layout(module_name, object=None):
                     for row in line:
                         single = False
                         nrow = []
-                        if isinstance(row, six.string_types):
+                        if isinstance(row, str):
                             single = True
                             row = [row]
                         for field in row:
