@@ -32,7 +32,6 @@
 
 """|UDM| type definitions."""
 
-from __future__ import absolute_import
 
 import datetime
 import inspect
@@ -41,7 +40,6 @@ from logging import getLogger
 from typing import Sequence, Type, Union  # noqa: F401
 
 import ldap.dn
-import six
 
 import univention.admin.uexceptions
 from univention.admin import localization
@@ -52,10 +50,6 @@ log = getLogger('ADMIN')
 translation = localization.translation('univention/admin')
 _ = translation.translate
 
-if six.PY3:
-    unicode = str
-    long = int
-
 _Types = Union[Type[object], Sequence[Type[object]]]
 
 
@@ -315,7 +309,7 @@ class TriBooleanType(BooleanType):
 
 
 class IntegerType(TypeHint):
-    _python_types = (int, long)
+    _python_types = int
     _openapi_type = 'integer'
     # _openapi_format: int32, int64
 
@@ -334,7 +328,7 @@ class NumberType(TypeHint):
 
 
 class StringType(TypeHint):
-    _python_types = unicode  # type: _Types
+    _python_types = str  # type: _Types
     _encoding = 'UTF-8'
     _openapi_type = 'string'
 
@@ -387,7 +381,7 @@ class BinaryType(TypeHint):
     _encoding = 'ISO8859-1'
 
     # It is not possible to transmit binary data via JSON. in JSON everything needs to be UTF-8!
-    _json_type = unicode
+    _json_type = str
     _json_encoding = 'ISO8859-1'
 
     _openapi_type = 'string'
@@ -413,7 +407,7 @@ class DateType(StringType):
     """
 
     _python_types = datetime.date
-    _json_type = unicode
+    _json_type = str
     _openapi_format = 'date'
 
     def decode_value(self, value):
@@ -424,10 +418,10 @@ class DateType(StringType):
     def encode_value(self, value):
         return self.syntax.from_datetime(value)
 
-    def _to_json_type(self, value):  # type: (datetime.date) -> unicode
-        return unicode(value.isoformat())
+    def _to_json_type(self, value):  # type: (datetime.date) -> str
+        return str(value.isoformat())
 
-    def _from_json_type(self, value):  # type: (unicode) -> datetime.date
+    def _from_json_type(self, value):  # type: (str) -> datetime.date
         try:
             return datetime.date(*time.strptime(value, '%Y-%m-%d')[0:3])
         except ValueError:
@@ -445,7 +439,7 @@ class TimeType(StringType):
     """
 
     _python_types = datetime.time
-    _json_type = unicode
+    _json_type = str
     _openapi_format = 'time'
 
     def decode_value(self, value):
@@ -456,10 +450,10 @@ class TimeType(StringType):
     def encode_value(self, value):
         return self.syntax.from_datetime(value)
 
-    def _to_json_type(self, value):  # type: (datetime.time) -> unicode
-        return unicode(value.replace(microsecond=0).isoformat())
+    def _to_json_type(self, value):  # type: (datetime.time) -> str
+        return str(value.replace(microsecond=0).isoformat())
 
-    def _from_json_type(self, value):  # type: (unicode) -> datetime.time
+    def _from_json_type(self, value):  # type: (str) -> datetime.time
         try:
             return datetime.time(*time.strptime(value, '%H:%M:%S')[3:6])
         except ValueError:
@@ -480,7 +474,7 @@ class DateTimeType(StringType):
     """
 
     _python_types = datetime.datetime
-    _json_type = unicode
+    _json_type = str
     _openapi_format = 'date-time'
 
     def decode_value(self, value):
@@ -491,10 +485,10 @@ class DateTimeType(StringType):
     def encode_value(self, value):
         return self.syntax.from_datetime(value)
 
-    def _to_json_type(self, value):  # type: (datetime.datetime) -> unicode
+    def _to_json_type(self, value):  # type: (datetime.datetime) -> str
         return u' '.join((value.date().isoformat(), value.time().replace(microsecond=0).isoformat()))
 
-    def _from_json_type(self, value):  # type: (unicode) -> datetime.datetime
+    def _from_json_type(self, value):  # type: (str) -> datetime.datetime
         try:
             return datetime.datetime(*time.strptime(value, '%Y-%m-%dT%H:%M:%S')[:6])  # FIXME: parse Z at the end
         except ValueError:
