@@ -32,8 +32,6 @@
 
 """|UDM| exceptions."""
 
-import six
-
 from univention.admin import localization
 from univention.admin._ucr import configRegistry
 
@@ -42,12 +40,6 @@ translation = localization.translation('univention/admin')
 _ = translation.translate
 
 
-def _str(string):
-    if six.PY2 and not isinstance(string, bytes):
-        string = string.encode('utf-8')
-    return str(string)
-
-
 def _strip(string):
     return string.strip().strip('.:').strip()
 
@@ -67,7 +59,7 @@ class base(Exception):
         for msg in self.args:
             if msg is None:
                 continue
-            msg = _str(msg)
+            msg = str(msg)
             # avoid duplicate messages
             if all(_strip(msg) not in arg for arg in args + [self.message]):
                 args.append(msg)
@@ -442,10 +434,6 @@ class templateSyntaxError(base):
         self.templates = templates
 
 
-class nagiosTimeperiodUsed(base):
-    message = _('Timeperiod Object still in use!')
-
-
 class nagiosARecordRequired(base):
     message = _('IP address entry required to assign Nagios services!')
 
