@@ -32,7 +32,6 @@
 
 """|UDM| wrapper around :py:mod:`univention.uldap` that replaces exceptions."""
 
-from __future__ import absolute_import
 
 import time
 from logging import getLogger
@@ -61,18 +60,13 @@ class DN(object):
     def __init__(self, dn):
         # type: (str) -> None
         self.dn = dn
-        self._hash = None
-        self._str = None
         try:
             self._dn = ldap.dn.str2dn(self.dn)
         except ldap.DECODING_ERROR:
             raise ValueError('Malformed DN syntax: %r' % (self.dn,))
 
     def __str__(self):
-        # compute string only once since the object is static
-        if self._str is None:
-            self._str = ldap.dn.dn2str(self._dn)
-        return self._str
+        return ldap.dn.dn2str(self._dn)
 
     def __unicode__(self):  # noqa: PLW3201
         return unicode(str(self))  # noqa: F821
@@ -109,11 +103,8 @@ class DN(object):
         return not self == other
 
     def __hash__(self):
-        # compute hash only once - object is static
         # TODO: attributes which's values are case insensitive should be respected
-        if self._hash is None:
-            self._hash = hash(tuple([tuple(sorted((x.lower(), y, z) for x, y, z in rdn)) for rdn in self._dn]))
-        return self._hash
+        return hash(tuple([tuple(sorted((x.lower(), y, z) for x, y, z in rdn)) for rdn in self._dn]))
 
     @classmethod
     def set(cls, values):
@@ -157,31 +148,29 @@ def getBaseDN(host='localhost', port=None, uri=None):
     return result[0][1]['namingContexts'][0].decode('utf-8')
 
 
-def getAdminConnection(start_tls=None, decode_ignorelist=[]):
-    # type: (int | None, list[str]) -> tuple[univention.admin.uldap.access, univention.admin.uldap.position]
+def getAdminConnection(start_tls=None, decode_ignorelist=None):
+    # type: (int | None, None) -> tuple[univention.admin.uldap.access, univention.admin.uldap.position]
     """
     Open a LDAP connection using the admin credentials.
 
     :param int start_tls: Negotiate TLS with server. If `2` is given, the command will require the operation to be successful.
-    :param decode_ignorelist: List of LDAP attribute names which shall be handled as binary attributes.
     :return: A 2-tuple (LDAP-access, LDAP-position)
     """
-    lo = univention.uldap.getAdminConnection(start_tls, decode_ignorelist=decode_ignorelist)
+    lo = univention.uldap.getAdminConnection(start_tls)
     pos = position(lo.base)
     return access(lo=lo), pos
 
 
-def getMachineConnection(start_tls=None, decode_ignorelist=[], ldap_master=True):
-    # type: (int | None, list[str], bool) -> tuple[univention.admin.uldap.access, univention.admin.uldap.position]
+def getMachineConnection(start_tls=None, decode_ignorelist=None, ldap_master=True):
+    # type: (int | None, None, bool) -> tuple[univention.admin.uldap.access, univention.admin.uldap.position]
     """
     Open a LDAP connection using the machine credentials.
 
     :param int start_tls: Negotiate TLS with server. If `2` is given, the command will require the operation to be successful.
-    :param decode_ignorelist: List of LDAP attribute names which shall be handled as binary attributes.
     :param bool ldap_master: Open a connection to the Primary if True, to the preferred LDAP server otherwise.
     :return: A 2-tuple (LDAP-access, LDAP-position)
     """
-    lo = univention.uldap.getMachineConnection(start_tls, decode_ignorelist=decode_ignorelist, ldap_master=ldap_master)
+    lo = univention.uldap.getMachineConnection(start_tls, ldap_master=ldap_master)
     pos = position(lo.base)
     return access(lo=lo), pos
 
