@@ -33,7 +33,6 @@
 
 """command line frontend to univention-directory-manager (module)"""
 
-from __future__ import print_function
 
 import base64
 import getopt
@@ -51,7 +50,6 @@ except ImportError:
     pass
 
 import ldap
-import six
 
 import univention.admin.modules
 import univention.admin.objects
@@ -228,13 +226,13 @@ def module_usage(
                 if isinstance(row, Group):
                     print('\t%s' % row.label, file=stream)
                     for row in row.layout:
-                        if isinstance(row, six.string_types):
+                        if isinstance(row, str):
                             _print_property(module, action, row, stream)
                             continue
                         for item in row:
                             _print_property(module, action, item, stream)
                 else:
-                    if isinstance(row, six.string_types):
+                    if isinstance(row, str):
                         _print_property(module, action, row, stream)
                         continue
                     for item in row:
@@ -329,7 +327,7 @@ def object_input(
             if values is None:
                 current_values = []
             else:
-                vallist = [values] if isinstance(values, six.string_types) else values
+                vallist = [values] if isinstance(values, str) else values
                 vallist = [module.property_descriptions[key].syntax.parse_command_line(x) for x in vallist]
 
                 for val in vallist:
@@ -490,7 +488,7 @@ def _doit(
             try:
                 with open(val) as fp:
                     bindpwd = fp.read().strip()
-            except IOError as exc:
+            except OSError as exc:
                 raise OperationFailed('E: could not read bindpwd from file (%s)' % (exc,))
         elif opt == '--dn':
             dn = val
@@ -536,7 +534,7 @@ def _doit(
                 try:
                     with open(secret_filename) as secretFile:
                         bindpwd = secretFile.read().strip('\n')
-                except IOError:
+                except OSError:
                     raise OperationFailed('E: Permission denied, try --binddn and --bindpwd')
                 policyOptions.extend(['-D', binddn, '-y', secret_filename])
                 break
@@ -997,10 +995,7 @@ class CLI(object):
                                     print('  %s: %s' % (key, None), file=self.stdout)
                         else:
                             if s.tostring(value):
-                                if module.module == 'settings/portal' and key == 'content':
-                                    print('  %s:\n  %s' % (key, s.tostring(value).replace('\n', '\n  ')), file=self.stdout)
-                                else:
-                                    print('  %s: %s' % (key, s.tostring(value)), file=self.stdout)
+                                print('  %s: %s' % (key, s.tostring(value)), file=self.stdout)
                             else:
                                 print('  %s: %s' % (key, None), file=self.stdout)
 
