@@ -32,7 +32,6 @@
 
 """Base classes for (simplified) UDM modules and objects."""
 
-from __future__ import absolute_import, unicode_literals
 
 import copy
 import pprint
@@ -42,7 +41,6 @@ from typing import (  # noqa: F401
 )
 
 from ldap.filter import filter_format
-from six import with_metaclass
 
 from .exceptions import MultipleObjects, NoObject
 from .plugins import Plugin
@@ -251,7 +249,7 @@ class ModuleMeta(Plugin):
         return new_cls
 
 
-class BaseModule(with_metaclass(ModuleMeta)):
+class BaseModule(metaclass=ModuleMeta):
     r"""
     Base class for UDM module classes. UDM modules are basically UDM object
     factories.
