@@ -32,7 +32,6 @@
 
 """En/Decoders for object properties."""
 
-from __future__ import absolute_import, unicode_literals
 
 import datetime
 import logging
@@ -41,7 +40,6 @@ import time
 from typing import Any, Callable, Dict, List, Optional, Type, TypeVar  # noqa: F401
 
 import lazy_object_proxy
-import six
 
 import univention.admin.modules
 from univention.admin.syntax import sambaGroupType
@@ -254,7 +252,7 @@ class SambaLogonHoursPropertyEncoder(BaseEncoder):
                 values = [v.split() for v in value]
                 return [cls._weekdays.index(w) * 24 + int(h.split('-', 1)[0]) for w, h in values]
             except (IndexError, ValueError):
-                six.reraise(valueInvalidSyntax, valueInvalidSyntax('One or more entries in sambaLogonHours have invalid syntax.'), sys.exc_info()[2])
+                raise valueInvalidSyntax('One or more entries in sambaLogonHours have invalid syntax.').with_traceback(sys.exc_info()[2])
         else:
             return value
 
@@ -268,7 +266,7 @@ class StringCaseInsensitiveResultLowerBooleanPropertyEncoder(BaseEncoder):
     @classmethod
     def decode(cls, value=''):
         # type: (Optional[str]) -> bool
-        return isinstance(value, six.string_types) and value.lower() == cls.true_string
+        return isinstance(value, str) and value.lower() == cls.true_string
 
     @classmethod
     def encode(cls, value=None):
@@ -312,7 +310,7 @@ class StringIntPropertyEncoder(BaseEncoder):
             try:
                 return int(value)
             except ValueError:
-                six.reraise(valueInvalidSyntax, valueInvalidSyntax('Value of {!r} must be an int (is {!r}).'.format(self.property_name, value)), sys.exc_info()[2])
+                raise valueInvalidSyntax('Value of {!r} must be an int (is {!r}).'.format(self.property_name, value)).with_traceback(sys.exc_info()[2])
 
     @staticmethod
     def encode(value=None):
@@ -639,7 +637,7 @@ def dn_list_property_encoder_for(udm_module_name):
     :return: subclass of DnListPropertyEncoder
     """
     if udm_module_name not in __dn_list_property_encoder_class_cache:
-        cls_name = str('DnListPropertyEncoder{}').format(_classify_name(udm_module_name))
+        cls_name = 'DnListPropertyEncoder{}'.format(_classify_name(udm_module_name))
         specific_encoder_cls = type(cls_name, (DnListPropertyEncoder,), {})
         specific_encoder_cls.udm_module_name = udm_module_name  # type: ignore[attr-defined]
         __dn_list_property_encoder_class_cache[udm_module_name] = specific_encoder_cls
@@ -658,7 +656,7 @@ def dn_property_encoder_for(udm_module_name):
     :return: subclass of DnPropertyEncoder
     """
     if udm_module_name not in __dn_property_encoder_class_cache:
-        cls_name = str('DnPropertyEncoder{}').format(_classify_name(udm_module_name))
+        cls_name = 'DnPropertyEncoder{}'.format(_classify_name(udm_module_name))
         specific_encoder_cls = type(cls_name, (DnPropertyEncoder,), {})
         specific_encoder_cls.udm_module_name = udm_module_name  # type: ignore[attr-defined]
         __dn_property_encoder_class_cache[udm_module_name] = specific_encoder_cls
