@@ -30,13 +30,7 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import unicode_literals
-
-
-try:
-    from typing import Collection, Optional  # noqa: F401
-except ImportError:
-    pass  # Python 2.7 🤮
+from typing import Collection, Optional  # noqa: F401
 
 
 class UdmError(Exception):
