@@ -35,7 +35,6 @@ A generic UDM module and object implementation.
 Will work for all kinds of UDM modules.
 """
 
-from __future__ import absolute_import, unicode_literals
 
 import copy
 import functools
@@ -47,7 +46,6 @@ from typing import Any, Dict, Iterable, Iterator, List, Optional, Tuple, Type, T
 
 import ldap
 from ldap.dn import dn2str, str2dn
-from six import reraise, string_types, with_metaclass
 
 import univention.admin.modules
 import univention.admin.objects
@@ -65,8 +63,6 @@ from ..exceptions import (
 )
 
 
-getfullargspec = getattr(inspect, 'getfullargspec', getattr(inspect, 'getargspec'))  # noqa: B009
-
 ucr = univention.config_registry.ConfigRegistry()
 ucr.load()
 DEFAULT_CONTAINERS_DN = 'cn=default containers,cn=univention,{}'.format(ucr['ldap/base'])
@@ -193,16 +189,16 @@ class GenericObject(BaseObject):
                 try:
                     self.dn = self._orig_udm_object.move(new_dn)
                 except univention.admin.uexceptions.invalidOperation as exc:
-                    reraise(MoveError, MoveError(
-                            'Moving {!r} object is not supported ({}).'.format(self._udm_module.name, exc),
-                            dn=self.dn, module_name=self._udm_module.name,
-                            ), sys.exc_info()[2])
+                    raise MoveError(
+                        'Moving {!r} object is not supported ({}).'.format(self._udm_module.name, exc),
+                        dn=self.dn, module_name=self._udm_module.name,
+                    ).with_traceback(sys.exc_info()[2])
                 except (univention.admin.uexceptions.base, ldap.error) as exc:
-                    reraise(MoveError, MoveError(
-                            'Error moving {!r} object from {!r} to {!r}: {}'.format(
-                                self._udm_module.name, self.dn, self.position, exc,
-                            ), dn=self.dn, module_name=self._udm_module.name,
-                            ), sys.exc_info()[2])
+                    raise MoveError(
+                        'Error moving {!r} object from {!r} to {!r}: {}'.format(
+                            self._udm_module.name, self.dn, self.position, exc,
+                        ), dn=self.dn, module_name=self._udm_module.name,
+                    ).with_traceback(sys.exc_info()[2])
                 assert self.dn == self._orig_udm_object.dn
                 self.position = self._lo.parentDn(self.dn)
                 self._old_position = self.position
@@ -210,27 +206,27 @@ class GenericObject(BaseObject):
             try:
                 self.dn = self._orig_udm_object.modify()
             except univention.admin.uexceptions.base as exc:
-                reraise(ModifyError, ModifyError(
-                        'Error saving {!r} object at {!r}: {}'.format(
-                            self._udm_module.name, self.dn, exc,
-                        ), dn=self.dn, module_name=self._udm_module.name,
-                        ), sys.exc_info()[2])
+                raise ModifyError(
+                    'Error saving {!r} object at {!r}: {}'.format(
+                        self._udm_module.name, self.dn, exc,
+                    ), dn=self.dn, module_name=self._udm_module.name,
+                ).with_traceback(sys.exc_info()[2])
             logging.getLogger('ADMIN').info('Modified %r object %r', self._udm_module.name, self.dn)
         else:
             try:
                 self.dn = self._orig_udm_object.create()
             except ldap.INVALID_DN_SYNTAX as exc:
-                reraise(CreateError, CreateError(
-                        'Error creating {!r} object: {}'.format(
-                            self._udm_module.name, exc,
-                        ), module_name=self._udm_module.name,
-                        ), sys.exc_info()[2])
+                raise CreateError(
+                    'Error creating {!r} object: {}'.format(
+                        self._udm_module.name, exc,
+                    ), module_name=self._udm_module.name,
+                ).with_traceback(sys.exc_info()[2])
             except univention.admin.uexceptions.base as exc:
-                reraise(CreateError, CreateError(
-                        'Error creating {!r} object: {}'.format(
-                            self._udm_module.name, exc,
-                        ), module_name=self._udm_module.name,
-                        ), sys.exc_info()[2])
+                raise CreateError(
+                    'Error creating {!r} object: {}'.format(
+                        self._udm_module.name, exc,
+                    ), module_name=self._udm_module.name,
+                ).with_traceback(sys.exc_info()[2])
             logging.getLogger('ADMIN').info('Created %r object %r', self._udm_module.name, self.dn)
 
         assert self.dn == self._orig_udm_object.dn
@@ -380,7 +376,7 @@ class GenericObject(BaseObject):
                 self._orig_udm_object[k] = new_val2
         if self.superordinate:
             # _orig_udm_object.superordinate is a orig UDM module
-            if isinstance(self.superordinate, string_types):
+            if isinstance(self.superordinate, str):
                 sup_obj = GenericModule(
                     self._udm_module._orig_udm_module.superordinate,
                     self._lo,
@@ -438,7 +434,7 @@ class GenericObject(BaseObject):
         else:
             assert self._udm_module is not None
             # initialize with required arguments
-            for arg in getfullargspec(encoder_class.__init__).args:
+            for arg in inspect.getfullargspec(encoder_class.__init__).args:
                 if arg == 'self':
                     continue
                 elif arg in kwargs:
@@ -514,7 +510,7 @@ class GenericModuleMeta(ModuleMeta):
     udm_meta_class = GenericModuleMetadata
 
 
-class GenericModule(with_metaclass(GenericModuleMeta, BaseModule)):
+class GenericModule(BaseModule, metaclass=GenericModuleMeta):
     """
     Simple API to use UDM modules. Basically a GenericObject factory.
 
@@ -610,12 +606,7 @@ class GenericModule(with_metaclass(GenericModuleMeta, BaseModule)):
         except univention.admin.uexceptions.ldapSizelimitExceeded:
             raise SearchLimitReached(module_name=self.name, search_filter=filter_s, sizelimit=sizelimit)
         for dn in dns:
-            try:
-                retrieved_obj = self.get(dn)
-            except NoObject:
-                logging.getLogger('ADMIN').warning('Skipping over search result with DN {!r}, that does not exist anymore'.format(dn))
-                continue
-            yield retrieved_obj
+            yield self.get(dn)
 
     def _dn_exists(self, dn):
         # type: (str) -> bool
@@ -716,7 +707,7 @@ class GenericModule(with_metaclass(GenericModuleMeta, BaseModule)):
         """
         udm_module = self._get_orig_udm_module()
         if superordinate:
-            if isinstance(superordinate, string_types):
+            if isinstance(superordinate, str):
                 superordinate_obj = univention.admin.objects.get_superordinate(udm_module, None, self.connection, superordinate)
             elif isinstance(superordinate, GenericObject):
                 superordinate_obj = superordinate._orig_udm_object
@@ -734,11 +725,11 @@ class GenericModule(with_metaclass(GenericModuleMeta, BaseModule)):
             obj = univention.admin.objects.get(udm_module, None, self.connection, po, dn=dn, superordinate=superordinate_obj)
             assert obj is not None
         except univention.admin.uexceptions.noObject:
-            reraise(NoObject, NoObject(dn=dn, module_name=self.name), sys.exc_info()[2])
+            raise NoObject(dn=dn, module_name=self.name).with_traceback(sys.exc_info()[2])
         except univention.admin.uexceptions.base as exc:
-            reraise(UdmError, UdmError(
-                    'Error loading UDM object at DN {!r}: {}'.format(dn, exc), dn=dn, module_name=self.name,
-                    ), sys.exc_info()[2])
+            raise UdmError(
+                'Error loading UDM object at DN {!r}: {}'.format(dn, exc), dn=dn, module_name=self.name,
+            ).with_traceback(sys.exc_info()[2])
         self._verify_univention_object_type(obj)
         if self.meta.auto_open:
             obj.open()
